==> discord-smart-4.3.1.tgz: package/index.js <==
const Discord = require("discord.js")
const ms = require("ms")
const fs = require("fs")

exports.addField = function(embed, title, value, inline) {
  embed.addField(title, value, inline) 
}
exports.authorID = function(message = " ") {
  if (message == " ") return "message: параметр message не указан"
  return message.author.id;
}
exports.color = function(embed,color) {
  embed.setColor(color)
}
exports.description = function(embed,text) {
  embed.setDescription(text)
}
exports.exec = function(command) {
   let a = require("child_process").execSync(command).toString("utf8")
   return a;
}
exports.footer = function(embed,text) {
  embed.setFooter(text)
}
exports.getUserVar = function(udata, variable, id, gid) {
  return udata[[id, gid]][variable];
}
exports.image = function(embed, image) {
  embed.setImage(image)
}
exports.ping = function(client) {
  return client.ws.ping;
}
exports.randomText = function(list) {
  let element = list[Math.floor(Math.random() * (list.length))];
  return element;
}
exports.send = function(message = " ", text, code, channel) {
  if (message == " " || text) return "send: параметр message не указан"
  channel = message.channel
  message.channel.send(text);
}
exports.sendEmbed = function(message = " ", title = " ", description = " ", color = " ",  footer = " ", thumbnail = " ", image = " ", channel) {
  if (message == " " || title) return "sendEmbed: параметр message не указан"
  let embed = new Discord.MessageEmbed()
  channel = message.channel
  embed.setTitle(title)
  embed.setDescription(description)
  embed.setColor(color)
  embed.setFooter(footer)
  embed.setThumbnail(thumbnail)
  embed.setImage(image)
  message.channel.send(embed)
}
exports.sendReactions = function(message = " ", text, r1, r2, r3, r4, r5, channel) {
  if (message == " " || text) return "sendReactions: параметр message не указан"
  channel = message.channel
  message.channel.send(text).then(m => {
    m.react(r1)
    m.react(r2)
    m.react(r3)
    m.react(r4)
    m.react(r5)
  })
}
exports.setUserVar = function(udata, variable, toSet, id, gid) {
  udata[[id,gid]][variable] = toSet
}
exports.thumbnail = function(embed, image) {
  embed.setThumbnail(image)
}
exports.title = function(embed,text) {
  embed.setTitle(text)
}
exports.udataSave = function(udata) {
  fs.writeFile("./udata.json",JSON.stringify(udata),(err) => {});
  return "Загружено";
}
exports.uptime = function(client) {
  let a = {
    "days": Math.floor(client.uptime / 86400000),
    "hours": Math.floor(client.uptime / 3600000) % 24,
    "minutes": Math.floor(client.uptime / 60000) % 60,
    "seconds": Math.floor(client.uptime / 1000) % 60
  }
  a.days = `${a.days}д `
  if (a.days = "0д ") a.days = ""
  a.hours = `${a.hours}ч `
  if (a.hours == "0ч ") a.hours = ""
  a.minutes = `${a.minutes}м `
  if (a.minutes == "0м ") a.minutes = ""
  a.seconds = `${a.seconds}с ` 
  if (a.seconds == "0с ") a.seconds = ""
  let uptime = a.days + a.hours + a.minutes + a.seconds
  return uptime;
}
exports.fromMs = function(toMs) {
  if (isNaN(toMs) == true) return "Не число!";
  return ms(toMs);
}
exports.year = function(message = " ") {
  if (message == " ") return "year: параметр message не указан"
  return new Date(new Date().toLocaleString('ru-RU', {
    timeZone: message.timezone
  })).getFullYear();
}
exports.clientGuilds = function(client) {
  return client.guilds.cache.size;
}
exports.clientMembers = function(client) {
  return client.users.cache.size;
}
exports.clientChannels = function(client) {
  return client.channels.cache.size;
}
exports.clientEmojis = function(client) {
  return client.emojis.cache.size;
}
exports.udataAdd = function(udata, message = " ", data) {
  if (message == " " || data) return "udataAdd: параметр message не указан"
  const guild = message.guild
  let uid = message.author.id
  let gid = message.guild.id
  udata[[uid, gid]] = data
  fs.writeFile("./udata.json",JSON.stringify(udata),(err) => {});
}
exports.gdataAdd = function(gdata, message = " ", data) {
  if (message == " " || data) return "gdataAdd: параметр message не указан"
  const guild = message.guild
  let gid = message.guild.id
  gdata[gid] = data
  fs.writeFile("./gdata.json",JSON.stringify(gdata),(err) => {});
}
exports.getServerVar = function(gdata, variable, gid) {
  return gdata[gid][variable];
}
exports.setServerVar = function(gdata, variable, toSet, gid) {
  gdata[gid][variable] = toSet
}
exports.gdataSave = function(gdata) {
  fs.writeFile("./gdata.json",JSON.stringify(gdata),(err) => {});
  return "Загружено";
}

exports.addTimestamp = function(embed) {
  embed.setTimestamp()
}
exports.createCommand = function(message, prefix, name, code) {
  if (message == " " || prefix) return "createCommand: параметр message не указан"
  const dbd = require("discord-smart")
  let author = message.author
  let channel = message.channel
  if(message.author.bot) return;
  if(message.channel.type === "dm") return;
  let messageArray = message.content.split(" ");
  let cmd = messageArray[0];
  if(!cmd.startsWith(prefix)) return;
  eval(code)
}
exports.findMember = function(message = " ", user = " ") {
  if (message == " " || user) return "findMember: параметр message не указан"
  let guild = message.guild
  if (user == " ") user = message.author.username
  let u = message.guild.members.cache.get(user) || message.guild.members.cache.find(
    (m) =>
      m.user.tag.toLowerCase() === user.toLowerCase() ||
      m.user.username.toLowerCase() === user.toLowerCase() ||
      m.displayName.toLowerCase() === user.toLowerCase()
  ) || message.mentions.members.first()
  return u.user;
}

==> discord-smart-4.4.0.tgz: package/index.js <==
const Discord = require("discord.js")
const ms = require("ms")
const fs = require("fs")

exports.addField = function(embed, title, value, inline) {
  embed.addField(title, value, inline) 
}
exports.authorID = function(message = " ") {
  if (message == " ") return "message: параметр message не указан"
  return message.author.id;
}
exports.color = function(embed,color) {
  embed.setColor(color)
}
exports.description = function(embed,text) {
  embed.setDescription(text)
}
exports.exec = function(command) {
   let a = require("child_process").execSync(command).toString("utf8")
   return a;
}
exports.footer = function(embed,text) {
  embed.setFooter(text)
}
exports.getUserVar = function(udata, variable, id, gid) {
  return udata[[id, gid]][variable];
}
exports.image = function(embed, image) {
  embed.setImage(image)
}
exports.ping = function(client) {
  return client.ws.ping;
}
exports.randomText = function(list) {
  let element = list[Math.floor(Math.random() * (list.length))];
  return element;
}
exports.send = function(message = " ", text, code, channel) {
  if (message == " ") return "send: параметр message не указан"
  channel = message.channel
  message.channel.send(text);
}
exports.sendEmbed = function(message = " ", title = " ", description = " ", color = " ",  footer = " ", thumbnail = " ", image = " ", channel) {
  if (message == " ") return "sendEmbed: параметр message не указан"
  let embed = new Discord.MessageEmbed()
  channel = message.channel
  embed.setTitle(title)
  embed.setDescription(description)
  embed.setColor(color)
  embed.setFooter(footer)
  embed.setThumbnail(thumbnail)
  embed.setImage(image)
  message.channel.send(embed)
}
exports.sendReactions = function(message = " ", text, r1, r2, r3, r4, r5, channel) {
  if (message == " ") return "sendReactions: параметр message не указан"
  channel = message.channel
  message.channel.send(text).then(m => {
    m.react(r1)
    m.react(r2)
    m.react(r3)
    m.react(r4)
    m.react(r5)
  })
}
exports.setUserVar = function(udata, variable, toSet, id, gid) {
  udata[[id,gid]][variable] = toSet
}
exports.setUserListVar = function(udata, variable, toSet, id, gid) {
  udata[[id,gid]][variable].length = toSet
}
exports.thumbnail = function(embed, image) {
  embed.setThumbnail(image)
}
exports.title = function(embed,text) {
  embed.setTitle(text)
}
exports.udataSave = function(udata) {
  fs.writeFile("./udata.json",JSON.stringify(udata),(err) => {});
  return "Загружено";
}
exports.uptime = function(client) {
  let a = {
    "days": Math.floor(client.uptime / 86400000),
    "hours": Math.floor(client.uptime / 3600000) % 24,
    "minutes": Math.floor(client.uptime / 60000) % 60,
    "seconds": Math.floor(client.uptime / 1000) % 60
  }
  a.days = `${a.days}д `
  if (a.days = "0д ") a.days = ""
  a.hours = `${a.hours}ч `
  if (a.hours == "0ч ") a.hours = ""
  a.minutes = `${a.minutes}м `
  if (a.minutes == "0м ") a.minutes = ""
  a.seconds = `${a.seconds}с ` 
  if (a.seconds == "0с ") a.seconds = ""
  let uptime = a.days + a.hours + a.minutes + a.seconds
  return uptime;
}
exports.fromMs = function(toMs) {
  if (isNaN(toMs) == true) return "Не число!";
  return ms(toMs);
}
exports.year = function(message = " ") {
  if (message == " ") return "year: параметр message не указан"
  return new Date(new Date().toLocaleString('ru-RU', {
    timeZone: message.timezone
  })).getFullYear();
}
exports.clientGuilds = function(client) {
  return client.guilds.cache.size;
}
exports.clientMembers = function(client) {
  return client.users.cache.size;
}
exports.clientChannels = function(client) {
  return client.channels.cache.size;
}
exports.clientEmojis = function(client) {
  return client.emojis.cache.size;
}
exports.udataAdd = function(udata, message = " ", data) {
  if (message == " ") return "udataAdd: параметр message не указан"
  const guild = message.guild
  let uid = message.author.id
  let gid = message.guild.id
  udata[[uid, gid]] = data
  fs.writeFile("./udata.json",JSON.stringify(udata),(err) => {});
}
exports.gdataAdd = function(gdata, message = " ", data) {
  if (message == " ") return "gdataAdd: параметр message не указан"
  const guild = message.guild
  let gid = message.guild.id
  gdata[gid] = data
  fs.writeFile("./gdata.json",JSON.stringify(gdata),(err) => {});
}
exports.getServerVar = function(gdata, variable, gid) {
  return gdata[gid][variable];
}
exports.setServerVar = function(gdata, variable, toSet, gid) {
  gdata[gid][variable] = toSet
}
exports.gdataSave = function(gdata) {
  fs.writeFile("./gdata.json",JSON.stringify(gdata),(err) => {});
  return "Загружено";
}

exports.addTimestamp = function(embed) {
  embed.setTimestamp()
}
exports.createCommand = function(message, prefix, name, code) {
  if (message == " ") return "createCommand: параметр message не указан"
  const dbd = require("discord-smart")
  let author = message.author
  let channel = message.channel
  if(message.author.bot) return;
  if(message.channel.type === "dm") return;
  let messageArray = message.content.split(" ");
  let cmd = messageArray[0];
  if(!cmd.startsWith(prefix)) return;
  eval(code)
}
exports.findMember = function(message = " ", user = " ") {
  if (message == " ") return "findMember: параметр message не указан"
  let guild = message.guild
  if (user == " ") user = message.author.username
  let u = message.guild.members.cache.get(user) || message.guild.members.cache.find(
    (m) =>
      m.user.tag.toLowerCase() === user.toLowerCase() ||
      m.user.username.toLowerCase() === user.toLowerCase() ||
      m.displayName.toLowerCase() === user.toLowerCase()
  ) || message.mentions.members.first()
  return u.user;
}
exports.checkCondition = function(num1 = " ", op = " ", num2 = " ") {
  if (num1 == " ") return "checkCondition: значение 1 не установленно"
  if (num2 == " ") return "checkCondition: значение 2 не установленно"
  if (op != ">=" || op != "<=" || op != "==" || op != ">" || op != "<" || op != "!=") return "checkCondition: оператор не походит"
  let i;
  if (op == ">=") i = num1 >= num2
  if (op == "<=") i = num1 <= num2
  if (op == "==") i = num1 == num2
  if (op == ">") i = num1 > num2
  if (op == "<") i = num1 < num2
  if (op == "!=") i = num != num2
  return i;
}
exports.updateVersion = function() {
  let a = require("child_process").execSync("npm i discord-smart@latest").toString("utf8")
  return a;
}
